# Clinica

Welcome to the [**Clinica**](http://www.clinica.run):
Software platform for clinical neuroimaging studies.

Full instructions for installation and additional information can be found in
the [user documentation](http://www.clinica.run/doc).


[![Build Status](https://ci.inria.fr/clinica-aramis/buildStatus/icon?job=clinica%2Fmaster)](https://ci.inria.fr/clinica-aramis/job/clinica/job/master/)
[![PyPI version](https://badge.fury.io/py/clinica.svg)](https://badge.fury.io/py/clinica)
[![conda install](https://anaconda.org/aramislab/clinica/badges/installer/conda.svg)](http://clinica.run/doc/Installation/)
[![platform](https://anaconda.org/aramislab/clinica/badges/platforms.svg)](http://clinica.run/doc/Installation/)
[![license](https://anaconda.org/aramislab/clinica/badges/license.svg)](http://clinica.run/doc/Installation/)
